@@ -122,6 +122,12 @@ extern "C" {
 #define SQL_COPT_SS_ACCESS_TOKEN                    (SQL_COPT_SS_BASE_EX+16) /* The authentication access token used for the connection */
 #define SQL_COPT_SS_USE_FMTONLY                     (SQL_COPT_SS_BASE_EX+17) /* The flag to SET FMTONLY ON/OFF */
 
+
+/* SQLSetConnectAttr MS driver additional specific defines. */
+#define SQL_COPT_SS_BASE_ADD                        1400
+#define SQL_COPT_SS_DATACLASSIFICATION_VERSION      (SQL_COPT_SS_BASE_ADD + 1) /* The flag to Set/Get DATACLASSIFICATION version support */
+
+
  /*
  * SQLColAttributes driver specific defines.
  * SQLSetDescField/SQLGetDescField driver specific defines.
